@@ -18,7 +18,7 @@
  *************************************************************************************/
 
 #include "plotsdictionarymodeltest.h"
-#include <QtTest/QTest>
+#include <QTest>
 #include <QStandardPaths>
 #include <QDebug>
 #include <qdir.h>
@@ -30,8 +30,6 @@ using namespace Analitza;
 
 QTEST_MAIN( PlotsDictionaryModelTest )
 
-Q_DECLARE_METATYPE(PlotItem*)
-
 PlotsDictionaryModelTest::PlotsDictionaryModelTest(QObject *parent)
     : QObject(parent)
 {}
